# QTRES - Process a single TRES image from a raw data file to a spectrum
# December 11, 2007
# By Doug Mink, SAO Telescope Data Center

procedure qtres (image)

string	image=""	{prompt="Image to process"}
string	imdate=""	{prompt="Date for images"}
string	instdir=""	{prompt="Directory containing date directories"}
real	gaincorr=1.0	{prompt="Gain correction for amp2 to amp1"}
bool	fixbias=no	{prompt="Fix bias section (yes or no)"}
bool	deltemp=yes	{prompt="Delete intermediate image files (y or n)"}
bool	saveold=yes	{prompt="Save unprocessed image files (y or n)"}
bool	verbose=yes	{prompt="Print process progress (y or n)"}

begin

file	imroot, amp1, amp2, temp2, imin, impath
string	imx, ims, imsec, history, imex
string	imd
bool	vb, dt, sv

	vb = verbose
	dt = deltemp
	sv = saveold
	imx = ".fits"
	imd = imdate
	imin = image

	if (imin == "") {
	    print ("QTRES: Reduce a single TRES image in a different directory")
	    print ("Usage: qtres image with both amps to be corrected")
	    return
	    }

# Copy image to current directory
	if (instdir != "") {
	    fixdir (instdir)
	    impath = fixdir.newdir
	    if (imd != "")
		impath = impath // imd // "/" // imin
	    else
		impath = impath // imin
	    if (!access (imin))
		copy (impath, imin)
	    }

# Remove overscan, trim, and merge amplifiers of image
	tpreproc.gaincorr = gaincorr
	tpreproc.fixbias = fixbias
	tpreproc.deltemp = dt
	tpreproc.saveold = sv
	tpreproc.verbose = vb
	tpreproc (imin)

# Remove pixel to pixel variation from image (including IR fringing)
	tflat.normfile = ""
	tflat.normdir = ""
	tflat.deltemp = dt
	tflat.saveold = sv
	tflat.verbose = vb
	tflat (imin)

# Extract spectra
	textract.aproot = ""
	textract.apdir = ""
	textract.deltemp = dt
	textract.verbose = vb
	textract (imin)

end

# Oct 12 2007	New task for quick look
# Dec 11 2007	Remove old declaration of instdir from before it was a parameter
