# TAPREF -- Set up local aperture reference files for a TRES spectrum
# By Doug Mink, SAO Telescope Data Center
# October 10, 2007

procedure tapref (image)

file	image=""	{prompt="Input image which needs aperture reference"}
file	aproot="flat"	{prompt="Root filename for aperature reference spectrum"}
file	apdir="tresdata$"	{prompt="Directory for reference spectra"}
bool	verbose=yes	{prompt="Log progress (y or n)"}
bool	debug=yes	{prompt="Print debugging information (y or n)"}

begin
	bool vb, db
	string apr
	file imin, imroot, templist, listfile
	file apfib1, apfib2, apfib3, adir, cwd
	file imfib1	# Aperture reference file for fiber 1
	file imfib2	# Aperture reference file for fiber 2
	file imfib3	# Aperture reference file for fiber 3
	file apreffib1, apreffib2, apreffib3
	file apfib1path, apfib2path, apfib3path
	file apfib1new, apfib2new, apfib3new
	file imfib1path, imfib2path, imfib3path, outfib1, outfib2, outfib3
	int lroot
	string history, tchar, args

	imin = image
	adir = apdir
	fixdir (adir)
	adir = fixdir.newdir
	if (adir == "")
	    adir = "tresdata$"
	apr = aproot
	if (apr == "")
	    apr = "flat"
	vb = verbose
	db = debug

	if (!access ("database/"))
	    mkdir ("database")
	pathname | scan (cwd)

	tresfib.verbose = vb
	tresfib (imin)
	if (db)
	    dpar ("tresfib")

# Fiber 1 (usually object)
	if (db)
	    print ("tresfib.fib1= ", tresfib.fib1)
	if (tresfib.fib1 != "OFF") {

# Get file names for fiber 1 reference image and aperture file
	    apreffib1 = apr // tresfib.apsize // tresfib.binning // "1"
	    imfib1 = apreffib1 // ".fits"
	    apfib1 = "ap" // apreffib1

# Copy fiber 1 reference image file to local directory
	    imfib1path = adir // imfib1
	    if (!access (imfib1)) {
		if (db)
		    print ("TAPREF: Copying ",imfib1path, " to ",cwd)
		args = osfn (imfib1path) // " " // imfib1
		lns (args)
		}
	    else if (db)
		print ("TAPREF: ",imfib1," already exists")

# Copy fiber 1 reference aperture file to local database/
	    apfib1path = adir // "database/" // apfib1
	    apfib1new = "database/" // apfib1
	    if (!access (apfib1new)) {
		if (db)
		    print ("TAPREF: ",apfib1path," => ", apfib1new)
		args = osfn (apfib1path) // " " // apfib1new
		lns (args)
		}
	    else if (db)
		print ("TAPREF: ",apfib1new," already exists")
	    }

# Fiber 2 (usually sky, but might be object)
	if (db)
	    print ("tresfib.fib2= ", tresfib.fib2)
	if (tresfib.fib2 != "OFF") {

# Get file names for fiber 2 reference image and aperture file
	    apreffib2 = apr // tresfib.apsize // tresfib.binning // "2"
	    imfib2 = apreffib2 // ".fits"
	    apfib2 = "ap" // apreffib2

# Copy fiber 2 reference image file to local directory
	    imfib2path = adir // imfib2
	    if (!access (imfib2)) {
		if (db)
		    print ("TAPREF: Copying ",imfib2path, " to ",cwd)
		args = osfn (imfib2path) // " " // imfib2
		lns (args)
		}
	    else if (db)
		print ("TAPREF: ",imfib2," already exists")

# Copy fiber 2 reference aperture file to local database/
	    apfib2path = adir // "database/" // apfib2
	    apfib2new = "database/" // apfib2
	    if (!access (apfib2new)) {
		if (db)
		    print ("TAPREF: ",apfib2path," => ", apfib2new)
		args = osfn (apfib2path) // " " // apfib2new
		lns (args)
		}
	    else if (db)
		print ("TAPREF: ",apfib2new," already exists")
	    }

# Fiber 3 calibration reference image
	if (db)
	    print ("tresfib.fib3= ", tresfib.fib3)
	if (tresfib.fib3 != "OFF") {

# Get file names for fiber 3 calibration reference image and aperture file
	    apreffib3 = apr // tresfib.apsize // tresfib.binning // "3"
	    imfib3 = apreffib3 // ".fits"
	    apfib3 = "ap" // apreffib3

# Copy fiber 3 calibration reference image file to local directory
	    imfib3path = adir // imfib3
	    if (!access (imfib3)) {
		if (db)
		    print ("TAPREF: Copying ",imfib3path, " to ",cwd)
		args = osfn (imfib3path) // " " // imfib3
		lns (args)
		}
	    else if (db)
		print ("TAPREF: ",imfib3," already exists")

# Copy fiber 3 calbibration reference aperture file to local database/
	    apfib3path = adir // "database/" // apfib3
	    apfib3new = "database/" // apfib3
	    if (!access (apfib3new)) {
		if (db)
		    print ("TAPREF: ",apfib3path," => ", apfib3new)
		args = osfn (apfib3path) // " " // apfib3new
		lns (args)
		}
	    else if (db)
		print ("TAPREF: ",apfib3new," already exists")
	    }

	return
end

# Oct  3 2007	New task
# Oct 10 2007	CL scripts cannot return parameters; make filenames internal
