# TFLAT -- Divide TRES image by pixel normalization file from tmakeflat
#          (apflatten), saving original file in Unflat/
# By Doug Mink, SAO Telescope Data Center
# December 19i,007

procedure tflat (images)

string	images = ""	{prompt="Input multispec image(s) to correct"}
string	normfile=""	{prompt="Pixel to pixel normalization file from apflatten"}
string	normdir="tresdata$"	{prompt="Directory for normfile"}
bool deltemp = no	{prompt="Delete temporary files (y or n)"}
bool saveold = yes	{prompt="Save original file to Nonorm/ (y or n)"}
bool verbose = yes	{prompt="Log progress (y or n)"}

begin
	bool vb, makename
	file imin, imout, imroot, imnorm, newfile, templist, ndir
	int lroot
	string history, ims, tchar

	ims = images
	vb = verbose
	imnorm = normfile
	if (imnorm == "")
	    makename=yes
	else
	    makename = no
	ndir = normdir
	fixdir (ndir)
	ndir = fixdir.newdir
	if (ndir == "") {
	    ndir = "tresdata$"
	    }

#  Make temporary list of input files
	tchar = substr (ims,1,1)
	if (tchar == '@') {
	    templist = substr (ims,2,100)
	    deltemp = no
	    }
	else {
            templist = mktemp ("flatlist")
            files (ims, >templist)
	    }
        list = templist
        while (fscan (list,imin) != EOF) {

# Do not flatten spectra twice
	    imgetp.default = "0"
	    imgetp (imin, "TFLAT")
	    if (imgetp.value != "0") {
		if (vb) {
		    print ("TFLAT: ", imin, " has been processed")
		    print ("TFLAT = ", imgetp.value)
		    }
		next
		}

# Remove extension from input file, if one is present, and make output file name
	    smatch (imin, ".fits")
	    if (smatch.found) {
		lroot = smatch.start - 1
		imout = substr (imin, 1, lroot) // ".flattened.fits"
		}
	    else {
		imout = imin // ".flattened.fits"
		imin = imin // ".fits"
		}
	    if (makename) {
		tresfib (imin)
		imnorm = ndir // "flat" // tresfib.apsize // tresfib.binning
		if (tresfib.fib1 != "OFF")
		    imnorm = imnorm // "1"
		if (tresfib.fib2 != "OFF")
		    imnorm = imnorm // "2"
		if (tresfib.fib3 != "OFF")
		    imnorm = imnorm // "3"
		imnorm = imnorm // ".flat.fits"
		}

# Add FITS extension to normalization file if it is missing
	    else {
		smatch (imnorm, ".fits")
		if (!smatch.found) {
		    imnorm = imnorm // ".fits"
		    }
		}

	    if (vb) {
		print ("TFLAT: ", imin," -> ",imout," using ", imnorm)
		}

# Divide out normalization spectra
	    imarith (imin, "/", imnorm, imout)

# Move original file to Unflat directory
	    if (saveold) {
		if (!access ("Unflat/")) {
		    mkdir ("Unflat")
		    }
		newfile = "Unflat/" // imin
		if (access (newfile)) {
		    imdelete (newfile)
		    }
		movefiles (imin, "Unflat")
		if (vb) {
		    print ("TFLAT: Original ", imin, " => Unflat/")
		    }
		}
	    else {
		delete (imin)
		}

# Rename result file to original file name
	    rename (imout, imin)

# Add history line including time
	    gettime ()
	    history = gettime.date // " " // gettime.time // " pixels normalized by " // imnorm
            hedit (imin, "TFLAT", history, add+, verify-)
	    }
	if (deltemp) {
	    delete (templist)
	    }

end
# Oct  2 2007	New task based on hectospec.hflat
# Oct 10 2007	Fix bug so that normfile name is always created if normfile=""
# Dec 19 2007	Default data directory to tresdata$
