# File tpreamp.cl
# Fix the 2 preamp images in a TRES exposure
# Doug Mink, October 18, 2007
#
# Input may be a comma-separated list or a filename (with prefaced "@")
# If output list not given, the updates are in place, else the output
# list must match the input in number.
#

procedure tpreamp (input)

string input = ""	{prompt="Image to correct"}

bool    deltemp=yes     {prompt="Delete intermediate image files (y or n)"}
bool    saveold=yes     {prompt="Save unprocessed image files (y or n)"}
bool    verbose=yes     {prompt="Print process progress (y or n)"}

begin

file	imroot, temp1, imin, templist, imout
string	imx, ims, imsec, history, tchar, pfix
bool	vb, dt, sv

    string inlist, outlist
    string tchar
    string pcsect1, psect2, psect3, psect4
    string fname
    file   imagei, imageo

    dt = deltemp
    ims = input
    sv = saveold
    vb = verbose
   
# Make directory in which to save raw multi-extension files
    if (sv) {
	if (!access ("Raw"))
	    mkdir ("Raw")
	}

#  Make temporary list of input files
    tchar = substr (ims,1,1)
    if (tchar == '@') {
	templist = substr (ims,2,100)
	deltemp = no
	}
    else {
	templist = mktemp ("proclist")
	files (ims, >templist)
	}

    list = templist
    while (fscan(list, imagei) != EOF) {
	if (vb)
	    printf("PREAMPFIX1: fix preamps on extns of %s\n",str(imagei))

# If preamp fix has been done, note it and go on to next image
	imgetp.default = ""
	imgetp (image, "PREAMPFX")
	if (imgetp.value != "") {
	    if (vb) {
		print ("PREAMPFIX already done for ",imagei)
		print ("PREAMPFIX: ",imgetp.value)
		}
	    next
	    }


# Copy image extensions to separate files and process them
	pfsect1 = imroot // "_0.fits"
	imcopy (imagei // "[0]", pfsect0, verbose=vb)

	pfsect1 = imroot // "_1.fits"
	imcopy (imagei // "[1]", pfsect1, verbose=vb)
	preamp1 (pfsect1)

	pfsect2 = imroot // "_2.fits"
	imcopy (imagei // "[2]", pfsect2, verbose=vb)
	preamp1 (pfsect2)

# Save the unchanged image to the Raw/ directory or delete it
	if (sv) {
	    outfile = "Raw/" // imagei
	    if (!access (outfile))
		rename (imagei, outfile)
	    else
		delete (imagei)
	    }
	else
	    delete (imagei)

# Reassemble the multi-extension FITS
	if(vb)
	    print("PREAMPFIX: joining ",imageo)

# Reassemble the input file with the fixed extensions
	mscjoin (imroot, output = imagei, delete=dt, verbose=vb)
	}

end

